package com.sun.org.apache.xml.internal.dtm.ref;

import org.w3c.dom.DOMException;
import org.w3c.dom.Node;
import com.sun.org.apache.xml.internal.dtm.DTM;
import org.w3c.dom.NamedNodeMap;

public class DTMNamedNodeMap implements NamedNodeMap
{
    DTM dtm;
    int element;
    short m_count;
    
    public DTMNamedNodeMap(DTM dtm, int element) {
        this.m_count = -1;
        this.dtm = dtm;
        this.element = element;
    }
    
    @Override
    public int getLength() {
        if (this.m_count == -1) {
            short count = 0;
            for (int n = this.dtm.getFirstAttribute(this.element); n != -1; n = this.dtm.getNextAttribute(n)) {
                ++count;
            }
            this.m_count = count;
        }
        return this.m_count;
    }
    
    @Override
    public Node getNamedItem(String name) {
        int n = this.dtm.getFirstAttribute(this.element);
        while (n != -1) {
            if (this.dtm.getNodeName(n).equals(name)) {
                return this.dtm.getNode(n);
            }
            n = this.dtm.getNextAttribute(n);
        }
        return null;
    }
    
    @Override
    public Node item(int i) {
        int count = 0;
        int n = this.dtm.getFirstAttribute(this.element);
        while (n != -1) {
            if (count == i) {
                return this.dtm.getNode(n);
            }
            ++count;
            n = this.dtm.getNextAttribute(n);
        }
        return null;
    }
    
    @Override
    public Node setNamedItem(Node newNode) {
        throw new DTMNamedNodeMap.DTMException((short)7);
    }
    
    @Override
    public Node removeNamedItem(String name) {
        throw new DTMNamedNodeMap.DTMException((short)7);
    }
    
    @Override
    public Node getNamedItemNS(String namespaceURI, String localName) {
        Node retNode = null;
        for (int n = this.dtm.getFirstAttribute(this.element); n != -1; n = this.dtm.getNextAttribute(n)) {
            if (localName.equals(this.dtm.getLocalName(n))) {
                String nsURI = this.dtm.getNamespaceURI(n);
                if ((namespaceURI == null && nsURI == null) || (namespaceURI != null && namespaceURI.equals(nsURI))) {
                    retNode = this.dtm.getNode(n);
                    break;
                }
            }
        }
        return retNode;
    }
    
    @Override
    public Node setNamedItemNS(Node arg) throws DOMException {
        throw new DTMNamedNodeMap.DTMException((short)7);
    }
    
    @Override
    public Node removeNamedItemNS(String namespaceURI, String localName) throws DOMException {
        throw new DTMNamedNodeMap.DTMException((short)7);
    }
    
    public class DTMException extends DOMException
    {
        static final long serialVersionUID = -8290238117162437678L;
        
        public DTMException(short code, String message) {
            super(code, message);
        }
        
        public DTMException(short code) {
            super(code, "");
        }
    }
}
